==> kubernetes-model-core-5.11.1-sources.jar: io/fabric8/kubernetes/api/model/PreferredSchedulingTermFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class PreferredSchedulingTermFluentImpl<A extends io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent<A>{
  public PreferredSchedulingTermFluentImpl() {
  }
  public PreferredSchedulingTermFluentImpl(io.fabric8.kubernetes.api.model.PreferredSchedulingTerm instance) {
    this.withPreference(instance.getPreference()); 
    this.withWeight(instance.getWeight()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.NodeSelectorTermBuilder preference;
  private java.lang.Integer weight;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildPreference instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.NodeSelectorTerm getPreference() {
    return this.preference!=null?this.preference.build():null;
  }
  public io.fabric8.kubernetes.api.model.NodeSelectorTerm buildPreference() {
    return this.preference!=null?this.preference.build():null;
  }
  public A withPreference(io.fabric8.kubernetes.api.model.NodeSelectorTerm preference) {
    _visitables.get("preference").remove(this.preference);
    if (preference!=null){ this.preference= new io.fabric8.kubernetes.api.model.NodeSelectorTermBuilder(preference); _visitables.get("preference").add(this.preference);} return (A) this;
  }
  public java.lang.Boolean hasPreference() {
    return this.preference != null;
  }
  public io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent.PreferenceNested<A> withNewPreference() {
    return new io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluentImpl.PreferenceNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent.PreferenceNested<A> withNewPreferenceLike(io.fabric8.kubernetes.api.model.NodeSelectorTerm item) {
    return new io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluentImpl.PreferenceNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent.PreferenceNested<A> editPreference() {
    return withNewPreferenceLike(getPreference());
  }
  public io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent.PreferenceNested<A> editOrNewPreference() {
    return withNewPreferenceLike(getPreference() != null ? getPreference(): new io.fabric8.kubernetes.api.model.NodeSelectorTermBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent.PreferenceNested<A> editOrNewPreferenceLike(io.fabric8.kubernetes.api.model.NodeSelectorTerm item) {
    return withNewPreferenceLike(getPreference() != null ? getPreference(): item);
  }
  public java.lang.Integer getWeight() {
    return this.weight;
  }
  public A withWeight(java.lang.Integer weight) {
    this.weight=weight; return (A) this;
  }
  public java.lang.Boolean hasWeight() {
    return this.weight != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PreferredSchedulingTermFluentImpl that = (PreferredSchedulingTermFluentImpl) o;
    if (preference != null ? !preference.equals(that.preference) :that.preference != null) return false;
    if (weight != null ? !weight.equals(that.weight) :that.weight != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(preference,  weight,  additionalProperties,  super.hashCode());
  }
  public class PreferenceNestedImpl<N> extends io.fabric8.kubernetes.api.model.NodeSelectorTermFluentImpl<io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent.PreferenceNested<N>> implements io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent.PreferenceNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PreferenceNestedImpl(io.fabric8.kubernetes.api.model.NodeSelectorTerm item) {
      this.builder = new io.fabric8.kubernetes.api.model.NodeSelectorTermBuilder(this, item);
    }
    PreferenceNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.NodeSelectorTermBuilder(this);
    }
    io.fabric8.kubernetes.api.model.NodeSelectorTermBuilder builder;
    public N and() {
      return (N) PreferredSchedulingTermFluentImpl.this.withPreference(builder.build());
    }
    public N endPreference() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/PreferredSchedulingTermFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class PreferredSchedulingTermFluentImpl<A extends io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent<A>{
  public PreferredSchedulingTermFluentImpl() {
  }
  public PreferredSchedulingTermFluentImpl(io.fabric8.kubernetes.api.model.PreferredSchedulingTerm instance) {
    this.withPreference(instance.getPreference()); 
    this.withWeight(instance.getWeight()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.NodeSelectorTermBuilder preference;
  private java.lang.Integer weight;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildPreference instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.NodeSelectorTerm getPreference() {
    return this.preference!=null?this.preference.build():null;
  }
  public io.fabric8.kubernetes.api.model.NodeSelectorTerm buildPreference() {
    return this.preference!=null?this.preference.build():null;
  }
  public A withPreference(io.fabric8.kubernetes.api.model.NodeSelectorTerm preference) {
    _visitables.get("preference").remove(this.preference);
    if (preference!=null){ this.preference= new io.fabric8.kubernetes.api.model.NodeSelectorTermBuilder(preference); _visitables.get("preference").add(this.preference);} return (A) this;
  }
  public java.lang.Boolean hasPreference() {
    return this.preference != null;
  }
  public io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent.PreferenceNested<A> withNewPreference() {
    return new io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluentImpl.PreferenceNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent.PreferenceNested<A> withNewPreferenceLike(io.fabric8.kubernetes.api.model.NodeSelectorTerm item) {
    return new io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluentImpl.PreferenceNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent.PreferenceNested<A> editPreference() {
    return withNewPreferenceLike(getPreference());
  }
  public io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent.PreferenceNested<A> editOrNewPreference() {
    return withNewPreferenceLike(getPreference() != null ? getPreference(): new io.fabric8.kubernetes.api.model.NodeSelectorTermBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent.PreferenceNested<A> editOrNewPreferenceLike(io.fabric8.kubernetes.api.model.NodeSelectorTerm item) {
    return withNewPreferenceLike(getPreference() != null ? getPreference(): item);
  }
  public java.lang.Integer getWeight() {
    return this.weight;
  }
  public A withWeight(java.lang.Integer weight) {
    this.weight=weight; return (A) this;
  }
  public java.lang.Boolean hasWeight() {
    return this.weight != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PreferredSchedulingTermFluentImpl that = (PreferredSchedulingTermFluentImpl) o;
    if (preference != null ? !preference.equals(that.preference) :that.preference != null) return false;
    if (weight != null ? !weight.equals(that.weight) :that.weight != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(preference,  weight,  additionalProperties,  super.hashCode());
  }
  public class PreferenceNestedImpl<N> extends io.fabric8.kubernetes.api.model.NodeSelectorTermFluentImpl<io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent.PreferenceNested<N>> implements io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent.PreferenceNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PreferenceNestedImpl(io.fabric8.kubernetes.api.model.NodeSelectorTerm item) {
      this.builder = new io.fabric8.kubernetes.api.model.NodeSelectorTermBuilder(this, item);
    }
    PreferenceNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.NodeSelectorTermBuilder(this);
    }
    io.fabric8.kubernetes.api.model.NodeSelectorTermBuilder builder;
    public N and() {
      return (N) PreferredSchedulingTermFluentImpl.this.withPreference(builder.build());
    }
    public N endPreference() {
      return and();
    }
    
  }
  
}
